==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Diagnoza.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.StatusDiagnozy;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Diagnoza extends GenericDPSObject {
    /**
     * DIAGNOZA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * DIAGNOZA.SLOWO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long slowoId;

    /**
     * DIAGNOZA.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusDiagnozy status;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DIAGNOZA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DIAGNOZA.SLOWO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * DIAGNOZA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return DIAGNOZA.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusDiagnozy getStatus() {
        return status;
    }

    /**
     * DIAGNOZA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusDiagnozy status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Diagnoza other = (Diagnoza) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Diagnoza.java <==
package pl.topteam.dps.model.main_gen;

import pl.topteam.dps.enums.StatusDiagnozy;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Diagnoza extends GenericDPSObject {
    /**
     * DIAGNOZA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * DIAGNOZA.SLOWO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long slowoId;

    /**
     * DIAGNOZA.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusDiagnozy status;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * DIAGNOZA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return DIAGNOZA.SLOWO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * DIAGNOZA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @return DIAGNOZA.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusDiagnozy getStatus() {
        return status;
    }

    /**
     * DIAGNOZA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusDiagnozy status) {
        this.status = status;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Diagnoza other = (Diagnoza) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", slowoId=").append(slowoId);
        sb.append(", status=").append(status);
        sb.append("]");
        return sb.toString();
    }
}
